@@ -49,7 +49,6 @@ class MainWindow(object):
         self.setupMenuTree()
         self.setupItemTree()
         self.tree.get_object('edit_delete').set_sensitive(False)
-        self.tree.get_object('edit_revert_to_original').set_sensitive(False)
         self.tree.get_object('edit_properties').set_sensitive(False)
         self.tree.get_object('move_up_button').set_sensitive(False)
         self.tree.get_object('move_down_button').set_sensitive(False)
@@ -209,7 +208,7 @@ class MainWindow(object):
             iters[menu] = self.menu_store.append(iters[parent], (icon, name, menu))
             self.loadMenu(iters, menu)
 
-    def loadItems(self, menu, menu_path):
+    def loadItems(self, menu):
         self.item_store.clear()
         for item, show in self.editor.getItems(menu):
             icon = util.getIcon(item)
@@ -302,17 +301,6 @@ class MainWindow(object):
         elif isinstance(item, GMenu.TreeSeparator):
             self.editor.deleteSeparator(item)
 
-    def on_edit_revert_to_original_activate(self, menu):
-        item_tree = self.tree.get_object('item_tree')
-        items, iter = item_tree.get_selection().get_selected()
-        if not iter:
-            return
-        item = items[iter][3]
-        if isinstance(item, GMenu.TreeEntry):
-            self.editor.revertItem(item)
-        elif isinstance(item, GMenu.TreeDirectory):
-            self.editor.revertMenu(item)
-
     def on_edit_properties_activate(self, menu):
         item_tree = self.tree.get_object('item_tree')
         items, iter = item_tree.get_selection().get_selected()
@@ -348,9 +336,8 @@ class MainWindow(object):
         menu_path = menus.get_path(iter)
         item_tree = self.tree.get_object('item_tree')
         item_tree.get_selection().unselect_all()
-        self.loadItems(self.menu_store[menu_path][2], menu_path)
+        self.loadItems(self.menu_store[menu_path][2])
         self.tree.get_object('edit_delete').set_sensitive(False)
-        self.tree.get_object('edit_revert_to_original').set_sensitive(False)
         self.tree.get_object('edit_properties').set_sensitive(False)
         self.tree.get_object('move_up_button').set_sensitive(False)
         self.tree.get_object('move_down_button').set_sensitive(False)
@@ -381,9 +368,6 @@ class MainWindow(object):
         self.tree.get_object('new_separator_button').set_sensitive(True)
         self.tree.get_object('delete_button').set_sensitive(True)
 
-        can_revert = self.editor.canRevert(item)
-        self.tree.get_object('edit_revert_to_original').set_sensitive(can_revert)
-
         can_edit = not isinstance(item, GMenu.TreeSeparator)
         self.tree.get_object('edit_properties').set_sensitive(can_edit)
         self.tree.get_object('properties_button').set_sensitive(can_edit)
@@ -454,12 +438,12 @@ class MainWindow(object):
     def on_help_button_clicked(self, *args):
         Gtk.show_uri(Gdk.Screen.get_default(), "ghelp:user-guide#menu-editor", Gtk.get_current_event_time())
 
-    def on_revert_button_clicked(self, button):
+    def on_restore_button_clicked(self, button):
         dialog = self.tree.get_object('revertdialog')
         dialog.set_transient_for(self.tree.get_object('mainwindow'))
         dialog.show_all()
         if dialog.run() == Gtk.ResponseType.YES:
-            self.editor.revert()
+            self.editor.restoreToSystem()
         dialog.hide()
 
     def on_close_button_clicked(self, button):
